am 235be391: Merge "Many, many developers misread or don\'t read the http specs and terminate lines with \'\n\' instead of CRLF \'\r\n\' as required. Enable the workaround for this by default. Also increase the socket read timeout to 30 secs." into gingerbread

Merge commit '235be391f3b9cd79e525de87757e361ae044940d' into gingerbread-plus-aosp

* commit '235be391f3b9cd79e525de87757e361ae044940d':
  Many, many developers misread or don't read the http specs and terminate lines with '\n' instead of CRLF '\r\n' as required. Enable the workaround for this by default. Also increase the socket read timeout to 30 secs.
diff --git a/media/libstagefright/HTTPStream.cpp b/media/libstagefright/HTTPStream.cpp
index 9c99866..ccc6a34 100644
--- a/media/libstagefright/HTTPStream.cpp
+++ b/media/libstagefright/HTTPStream.cpp
@@ -68,7 +68,7 @@
         return UNKNOWN_ERROR;
     }
 
-    setReceiveTimeout(5);  // Time out reads after 5 secs by default
+    setReceiveTimeout(30);  // Time out reads after 30 secs by default
 
     mState = CONNECTING;
 
@@ -158,7 +158,7 @@
 // The workaround accepts both behaviours but could potentially break
 // legitimate responses that use a single newline to "fold" headers, which is
 // why it's not yet on by default.
-#define WORKAROUND_FOR_MISSING_CR       0
+#define WORKAROUND_FOR_MISSING_CR       1
 
 status_t HTTPStream::receive_line(char *line, size_t size) {
     if (mState != CONNECTED) {